@@ -1,4 +1,4 @@
-# $Id: Pipe.pm,v 1.17 2005/12/26 13:57:47 joern Exp $
+# $Id: Pipe.pm,v 1.18 2006/03/27 20:15:39 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2003 Jrn Reder <joern AT zyn.de>.
@@ -91,7 +91,7 @@ sub open {
         open( STDERR, ">&STDOUT" )
             or croak "can't dup STDOUT to STDERR";
         my $command = $self->command;
-        $command = "dvdrip-exec $command" if $command !~ /dvdrip-exec/;
+        $command = "execflow $command" if $command !~ /execflow/;
         exec($command)
             or croak "can't exec program: $!";
     }
